# scatterplot.py
# ------------
# By MWC Contributors
# Uses lots of helper functions in other modules to draw a scatter plot.

from turtle import *
from superturtle.movement import no_delay
import constants
from generate_data import generate_data
from ticks import get_tick_values
from plotting import (
    prepare_screen, 
    draw_x_axis, 
    draw_y_axis,
    draw_x_tick, 
    draw_y_tick,
    draw_point, 
)
from transform import (
    maximum, 
    minimum,
    bounds, 
    clamp,
    ratio, 
    scale,
    get_x_values,
    get_y_values,
)

def draw_scatterplot(data, size, color):
    "Draws a scatter plot, showing the data"
    prepare_screen()
    draw_axes(data)
    draw_points(data, color, size)

def draw_axes(data):
    "Draws the scatter plot's axes."
    

    draw_x_axis()
    x_values = get_x_values(data)
    xmin, xmax = bounds(x_values)
    ticks = get_tick_values(xmin, xmax)
    for tick in ticks:
        screen_x_position = scale(tick, xmin, xmax, 0, constants.PLOT_WIDTH)
        draw_x_tick(screen_x_position, tick)

    draw_y_axis()
    y_values = get_y_values(data)
    ymin, ymax = bounds(y_values)
    ticks = get_tick_values(ymin, ymax)
    for tick in ticks:
        screen_y_position = scale(tick, ymin, ymax, 0, constants.PLOT_WIDTH)
        draw_y_tick(screen_y_position, tick)


def draw_points(data, color, size):
    "Draws the scatter plot's points."
    xmin, xmax = bounds(get_x_values(data))
    ymin, ymax = bounds(get_y_values(data))
    """draw_point(100, 100, color="blue", size = 5)"""
    for point in data:
        x = point[0]
        y = point[1]
        x_scaled = scale(x, xmin, xmax, 0, constants.PLOT_WIDTH)
        y_scaled = scale(y, ymin, ymax, 0, constants.PLOT_HEIGHT)
        print(f"Printing point onto the screen at ({x_scaled}, {y_scaled})")
        draw_point(x_scaled, y_scaled, color, size)


with no_delay():
    data = generate_data(50, 10, 500, 5, 400, 1000)
    draw_scatterplot(data, size=5, color="blue")
    hideturtle()
done()
